@@ -1,5 +1,6 @@
 import asyncio
 import datetime
+import calendar
 import functools
 import json
 import os
@@ -147,13 +148,13 @@ class FinXRest:
         return response
 
     @Hybrid
-    async def pair_quote_series(self, pair: str, unix_time_start: str,  unix_time_end: str, timeslice_width_seconds:str) -> pd.DataFrame:
+    async def pair_quote_series(self, pair: str, unix_time_start: str,  unix_time_end: str, time_target_width:str) -> pd.DataFrame:
         number_of_periods = 100
         distance_between_periods = (int(unix_time_end) - int(unix_time_start)) / number_of_periods
         print('running time series of pair quotes with ' + str(number_of_periods) + ' periods from ' + str(unix_time_start) + ' to ' + str(unix_time_end))
         for i in range(number_of_periods):
             timeslice_datestamp = int(unix_time_start) + (i*distance_between_periods)
-            this_frame = await self.pair_quote(pair, str(timeslice_datestamp), timeslice_width_seconds)
+            this_frame = await self.pair_quote(pair, str(timeslice_datestamp), time_target_width)
             print('this_frame:'+str(i), this_frame)
             if i == 0:
                 return_df = pd.DataFrame.from_records([this_frame])
@@ -164,8 +165,8 @@ class FinXRest:
                         return_df = pd.concat([return_df, add_df], ignore_index=True)
                 except:
                     continue
-        return_df['datetime'] = return_df['unix_time'].to_datetime()
-        return_df['price'] = return_df['price'].astype(float)
+        return_df['datetime'] = return_df.apply(lambda row: row['unix_time'].to_datetime())
+        return_df['price_f'] = return_df.apply(lambda row: row['price'].astype(float))
         return return_df
 
     @Hybrid
@@ -182,10 +183,11 @@ class FinXRest:
 
     @Hybrid
     async def get_options_timeslice_series(self, unix_time_start, unix_time_end, timeslice_width_seconds, underlying_symbol) -> pd.DataFrame:
-        number_of_periods = int((int(unix_time_end) - int(unix_time_start)) / int(unix_time_end))
+        number_of_periods = 10
+        period_length = int((int(unix_time_end) - int(unix_time_start)) / int(number_of_periods))
         print('running time series of timeslices with ' + str(number_of_periods) + ' periods from ' + str(unix_time_start) + ' to ' + str(unix_time_end))
         for i in range(number_of_periods):
-            timeslice_datestamp = int(unix_time_start) + (i*int(unix_time_end))
+            timeslice_datestamp = int(unix_time_start) + (i*period_length)
             this_frame = await self.get_options_timeslice(str(timeslice_datestamp), str(timeslice_width_seconds), underlying_symbol)
             print('this_frame:'+str(i), this_frame)
             if i == 0:
@@ -199,48 +201,31 @@ class FinXRest:
         print("row", row)
         instrument_name = row['instrument_name']
         years_to_expiry = 0.0
-        try:
-            day_value = instrument_name.split("-")[1][0:2]
-            month_value = instrument_name.split("-")[1][2:5]
-            year_value = instrument_name.split("-")[1][5:8]
-            day_int = int(day_value)
-        except:
-            day_value = instrument_name.split("-")[1][0:1]
-            month_value = instrument_name.split("-")[1][1:4]
-            year_value = instrument_name.split("-")[1][4:7]
+        day_value = instrument_name.split("-")[1][0:2]
+        month_value = instrument_name.split("-")[1][2:5]
+        year_value = instrument_name.split("-")[1][5:8]
         date_string = year_value + '/' + month_value + '/' + day_value
         expiry_unix = datetime.datetime.strptime(date_string, '%y/%b/%d').timestamp()
-        years_to_expiry = round((expiry_unix - time.time())) / 60 / 60 / 24 / 365
+        years_to_expiry = (expiry_unix - time.time()) / 60 / 60 / 24 / 365
         return years_to_expiry
 
     def _parse_strike_price(self, row):
         return row['instrument_name'].split("-")[2]
 
-    def _remove_incomplete_observation_sets(self,expiration_count, row):
-        if int(row.strike) < int(expiration_count):
-            return 'delete'
-        else:
-            return 'keep'
-
     @Hybrid
     async def prepare_vol_surface_inputs(self, filename, timeslice_datestamp, timeslice_width_seconds, underlying_symbol) -> str:
         df = pd.DataFrame(await self.get_options_timeslice(timeslice_datestamp, timeslice_width_seconds, underlying_symbol))
-        # print('vol_surface_inputs raw:', df)
-        df['years_to_expiry'] = df.apply(lambda row: self._calc_years_to_expiry(row), axis=1).astype(str)
+        print('vol_surface_inputs raw:', df)
+        df['years_to_expiry'] = df.apply(lambda row: self._calc_years_to_expiry(row), axis=1)
         df['strike_price'] = df.apply(lambda row: self._parse_strike_price(row), axis=1)
         output_df = df[['years_to_expiry', 'strike_price', 'mark_iv']]
-        renamed_df = output_df.rename(columns={"years_to_expiry": "expiration", "strike_price": "strike", "mark_iv": "price"})
+        output_df.rename(columns={"years_to_expiry": "expiration", "strike_price": "price", "mark_iv": "price"})
         # must be expiration,strike,price
         #,redis_key,underlying_price,underlying_index,timestamp,state,settlement_price,open_interest,min_price,max_price,mark_price,mark_iv,last_price,interest_rate,instrument_name,index_price,estimated_delivery_price,bid_iv,best_bid_price,best_bid_amount,best_ask_price,best_ask_amount,ask_iv,vega,theta,rho,gamma,delta,volume,price_change,low,high
-        unique_strikes_df = renamed_df.drop_duplicates(subset=['expiration', 'strike'], keep='last')
-        sorted_df = unique_strikes_df.sort_values(by=['expiration', 'strike']).copy()
-        grouped_df = sorted_df.groupby(by=['expiration'], as_index=False).count()
-        expiration_count = len(grouped_df)
-        sorted_df['action'] = sorted_df.apply(lambda row: self._remove_incomplete_observation_sets(expiration_count, grouped_df.loc[grouped_df['expiration'] == row.expiration]), axis=1)
-        keeper_df = sorted_df.loc[sorted_df['action'] == 'keep'].copy()
-        keeper_df.to_csv(filename, columns=['expiration', 'strike', 'price'], index=False)
+        output_df.to_csv(filename, index=False)
         return filename
 
     @Hybrid
     async def connect(self):
         await self.__aenter__()
+
